"""Add all commands to Nuke's UI and register callbacks."""

# Import built-in modules
import os

# Import third-party modules
import nuke

# Import local modules
from smartLook import osl as smartlook
from smartLook import helper


def add_to_ui():
    """Add menu and all containing commands to Nuke's UI."""
    # Main smartLook menu
    menu = nuke.menu("Nuke").addMenu(
        "cragl/smartLook", icon=helper.load_icons()["icon_logo"])

    # Snapshot section
    menu.addCommand("snapshot browser", smartlook.show_snapshot_browser)
    menu.addCommand("take snapshot", smartlook.snapshot)
    menu.addSeparator()

    # Looks section
    menu.addCommand("looks slider", smartlook.show_looks_slider)
    menu.addCommand("set looks", smartlook.batch_set_look)
    menu.addCommand("delete selected node's looks",
                    smartlook.delete_selected_nodes_looks)
    menu.addSeparator()

    # Import/ export section
    menu.addCommand("import node | toolset", smartlook.import_preset)
    menu.addCommand("export node | toolset", smartlook.export_nodes)
    menu.addSeparator()

    # Resolution slider
    menu.addCommand("resolution slider", smartlook.showRezSlider, "N")
    menu.addCommand("resolution/1",
                    lambda: smartlook.set_resolution("0.0"), "Ctrl+Alt+1")
    menu.addCommand("resolution/2",
                    lambda: smartlook.set_resolution("1.0"), "Ctrl+Alt+2")
    menu.addCommand("resolution/4",
                    lambda: smartlook.set_resolution("2.0"), "Ctrl+Alt+3")
    menu.addCommand("resolution/8",
                    lambda: smartlook.set_resolution("3.0"), "Ctrl+Alt+4")
    menu.addCommand("resolution/16",
                    lambda: smartlook.set_resolution("4.0"), "Ctrl+Alt+5")
    menu.addCommand("resolution/32",
                    lambda: smartlook.set_resolution("5.0"), "Ctrl+Alt+6")

    menu.addSeparator()

    # Settings
    menu.addCommand("&settings", smartlook.show_settings)
    menu.addSeparator()

    # About
    menu.addCommand("&about", smartlook.show_about_window)

    # Add set look command
    nuke.menu("Properties").addCommand(
        "set look", lambda: smartlook.set_look(nuke.selectedNode()))

    # Add icons folder to properly display icons.
    icons_dir = os.path.join(os.path.dirname(__file__), "smartLook", "icons")
    nuke.pluginAddPath(icons_dir)

    # Dynamically set hotkeys
    helper.set_hotkeys()


add_to_ui()
